@@ -1,22 +1,7 @@
-// "$Id: $"
-//
-// FLTK native file chooser widget wrapper for GTK's GtkFileChooserDialog 
-//
-// Copyright 1998-2013 by Bill Spitzak and others.
-// Copyright 2012 IMM
-//
-// This library is free software. Distribution and use rights are outlined in
-// the file "COPYING" which should have been included with this file.  If this
-// file is missing or damaged, see the license at:
-//
-//     http://www.fltk.org/COPYING.php
-//
-// Please report all bugs and problems to:
-//
-//     http://www.fltk.org/str.php
-//
-
 #include <FL/Fl_Native_File_Chooser.H>
+
+#if SEAVIEW_FLTK_VERSION < 133
+
 #include <FL/Fl_File_Icon.H>
 
 #include "Fl_Native_File_Chooser_common.cxx"
@@ -31,14 +16,14 @@
 // TMP until GTK chooser is integrated in FLTK
 const char *mgFl_Native_File_Chooser::file_exists_message = "File exists. Are you sure you want to overwrite?";
 
-int Fl_Native_File_Chooser::have_looked_for_GTK_libs = 0;
+int mgFl_Native_File_Chooser::have_looked_for_GTK_libs = 0;
 
 /**
  The constructor. Internally allocates the native widgets.
  Optional \p val presets the type of browser this will be, 
  which can also be changed with type().
  */
-Fl_Native_File_Chooser::Fl_Native_File_Chooser(int val) {
+mgFl_Native_File_Chooser::mgFl_Native_File_Chooser(int val) {
 #if FLTK_ABI_VERSION <= 10302
   _btype       = val;
   _options     = NO_OPTIONS;
@@ -53,36 +38,36 @@ Fl_Native_File_Chooser::Fl_Native_File_Chooser(int val) {
 #ifdef USE_GTK_FILE_CHOOSER
   if(have_looked_for_GTK_libs == 0) {
     // First Time here, try to find the GTK libs if they are installed
-    Fl_GTK_File_Chooser::probe_for_GTK_libs();
+    mgFl_GTK_File_Chooser::probe_for_GTK_libs();
     have_looked_for_GTK_libs = -1;
   }
   
   // if we found all the GTK functions we need, we will use the GtkFileChooserDialog
-  if (Fl_GTK_File_Chooser::did_find_GTK_libs) _gtk_file_chooser = new Fl_GTK_File_Chooser(val);
+  if (mgFl_GTK_File_Chooser::did_find_GTK_libs) _gtk_file_chooser = new mgFl_GTK_File_Chooser(val);
   else 
 #endif // USE_GTK_FILE_CHOOSER
-    _x11_file_chooser = new Fl_FLTK_File_Chooser(val);
+    _x11_file_chooser = new mgFl_FLTK_File_Chooser(val);
 }
 
 /**
  Destructor. 
  Deallocates any resources allocated to this widget.
  */
-Fl_Native_File_Chooser::~Fl_Native_File_Chooser() {
+mgFl_Native_File_Chooser::~mgFl_Native_File_Chooser() {
   delete _x11_file_chooser;
 }
 
 /**
- Sets the current Fl_Native_File_Chooser::Type of browser.
+ Sets the current mgFl_Native_File_Chooser::Type of browser.
  */
-void Fl_Native_File_Chooser::type(int t) { return _x11_file_chooser->type(t); }
+void mgFl_Native_File_Chooser::type(int t) { return _x11_file_chooser->type(t); }
 /**
- Gets the current Fl_Native_File_Chooser::Type of browser.
+ Gets the current mgFl_Native_File_Chooser::Type of browser.
  */
-int Fl_Native_File_Chooser::type() const { return _x11_file_chooser->type(); }
+int mgFl_Native_File_Chooser::type() const { return _x11_file_chooser->type(); }
 /**
  Sets the platform specific chooser options to \p val.
- \p val is expected to be one or more Fl_Native_File_Chooser::Option flags ORed together.
+ \p val is expected to be one or more mgFl_Native_File_Chooser::Option flags ORed together.
  Some platforms have OS-specific functions that can be enabled/disabled via this method.
  <P>
  \code
@@ -94,11 +79,11 @@ int Fl_Native_File_Chooser::type() const { return _x11_file_chooser->type(); }
  USE_FILTER_EXT    Chooser filter pilots the output file extension.  Ignored   Used      Ignored
 \endcode
  */
-void Fl_Native_File_Chooser::options(int o) {  _x11_file_chooser->options(o); }
+void mgFl_Native_File_Chooser::options(int o) {  _x11_file_chooser->options(o); }
 /**
- Gets the platform specific Fl_Native_File_Chooser::Option flags.
+ Gets the platform specific mgFl_Native_File_Chooser::Option flags.
  */
-int Fl_Native_File_Chooser::options() const {  return _x11_file_chooser->options(); }
+int mgFl_Native_File_Chooser::options() const {  return _x11_file_chooser->options(); }
 
 /**
  Returns the number of filenames (or directory names) the user selected.
@@ -113,14 +98,14 @@ int Fl_Native_File_Chooser::options() const {  return _x11_file_chooser->options
  }
  \endcode
  */
-int Fl_Native_File_Chooser::count() const { return _x11_file_chooser->count(); }
+int mgFl_Native_File_Chooser::count() const { return _x11_file_chooser->count(); }
 /**
  Return the filename the user chose.
  Use this if only expecting a single filename.
  If more than one filename is expected, use filename(int) instead.
  Return value may be "" if no filename was chosen (eg. user cancelled).
  */
-const char *Fl_Native_File_Chooser::filename() const { return _x11_file_chooser->filename(); }
+const char *mgFl_Native_File_Chooser::filename() const { return _x11_file_chooser->filename(); }
 /**
  Return one of the filenames the user selected.
  Use count() to determine how many filenames the user selected.
@@ -135,33 +120,33 @@ const char *Fl_Native_File_Chooser::filename() const { return _x11_file_chooser-
  }
  \endcode
  */
-const char *Fl_Native_File_Chooser::filename(int i) const { return _x11_file_chooser->filename(i); }
+const char *mgFl_Native_File_Chooser::filename(int i) const { return _x11_file_chooser->filename(i); }
 /**
  Preset the directory the browser will show when opened.
  If \p val is NULL, or no directory is specified, the chooser will attempt
  to use the last non-cancelled folder.
  */
-void Fl_Native_File_Chooser::directory(const char *val) {  _x11_file_chooser->directory(val); }
+void mgFl_Native_File_Chooser::directory(const char *val) {  _x11_file_chooser->directory(val); }
 /**
  Returns the current preset directory() value.
  */
-const char *Fl_Native_File_Chooser::directory() const { return _x11_file_chooser->directory(); }
+const char *mgFl_Native_File_Chooser::directory() const { return _x11_file_chooser->directory(); }
 /**
  Set the title of the file chooser's dialog window.
  Can be NULL if no title desired.
  The default title varies according to the platform, so you are advised to set the title explicitly.
  */
-void Fl_Native_File_Chooser::title(const char *t) {  _x11_file_chooser->title(t); }
+void mgFl_Native_File_Chooser::title(const char *t) {  _x11_file_chooser->title(t); }
 /**
  Get the title of the file chooser's dialog window.
  Return value may be NULL if no title was set.
  */
-const char* Fl_Native_File_Chooser::title() const { return _x11_file_chooser->title(); }
+const char* mgFl_Native_File_Chooser::title() const { return _x11_file_chooser->title(); }
 /**
  Returns the filter string last set.
  Can be NULL if no filter was set.
  */
-const char *Fl_Native_File_Chooser::filter() const { return _x11_file_chooser->filter(); }
+const char *mgFl_Native_File_Chooser::filter() const { return _x11_file_chooser->filter(); }
 /**
  Sets the filename filters used for browsing. 
  The default is NULL, which browses all files.
@@ -180,11 +165,11 @@ const char *Fl_Native_File_Chooser::filter() const { return _x11_file_chooser->f
  On most platforms, each filter is available to the user via a pulldown menu 
  in the file chooser. The 'All Files' option is always available to the user. 
  */
-void Fl_Native_File_Chooser::filter(const char *f) {  _x11_file_chooser->filter(f); }
+void mgFl_Native_File_Chooser::filter(const char *f) {  _x11_file_chooser->filter(f); }
 /**
  Gets how many filters were available, not including "All Files" 
  */
-int Fl_Native_File_Chooser::filters() const { return _x11_file_chooser->filters(); }
+int mgFl_Native_File_Chooser::filters() const { return _x11_file_chooser->filters(); }
 /**
  Sets which filter will be initially selected.
  
@@ -192,29 +177,29 @@ int Fl_Native_File_Chooser::filters() const { return _x11_file_chooser->filters(
  If filter_value()==filters(), then "All Files" was chosen. 
  If filter_value() > filters(), then a custom filter was set.
  */
-void Fl_Native_File_Chooser::filter_value(int i) {  _x11_file_chooser->filter_value(i); }
+void mgFl_Native_File_Chooser::filter_value(int i) {  _x11_file_chooser->filter_value(i); }
 /**
  Returns which filter value was last selected by the user.
  This is only valid if the chooser returns success.
  */
-int Fl_Native_File_Chooser::filter_value() const { return _x11_file_chooser->filter_value(); }
+int mgFl_Native_File_Chooser::filter_value() const { return _x11_file_chooser->filter_value(); }
 /**
  Sets the default filename for the chooser.
  Use directory() to set the default directory.
  Mainly used to preset the filename for save dialogs, 
  and on most platforms can be used for opening files as well. 
  */
-void Fl_Native_File_Chooser::preset_file(const char* f) {  _x11_file_chooser->preset_file(f); }
+void mgFl_Native_File_Chooser::preset_file(const char* f) {  _x11_file_chooser->preset_file(f); }
 /**
  Get the preset filename.
  */
-const char* Fl_Native_File_Chooser::preset_file() const { return _x11_file_chooser->preset_file(); }
+const char* mgFl_Native_File_Chooser::preset_file() const { return _x11_file_chooser->preset_file(); }
 /**
  Returns a system dependent error message for the last method that failed. 
  This message should at least be flagged to the user in a dialog box, or to some kind of error log. 
  Contents will be valid only for methods that document errmsg() will have info on failures.
  */
-const char *Fl_Native_File_Chooser::errmsg() const { return _x11_file_chooser->errmsg(); }
+const char *mgFl_Native_File_Chooser::errmsg() const { return _x11_file_chooser->errmsg(); }
 /**
  Post the chooser's dialog. Blocks until dialog has been completed or cancelled.
  \returns
@@ -222,10 +207,10 @@ const char *Fl_Native_File_Chooser::errmsg() const { return _x11_file_chooser->e
  - 1  -- user cancelled
  - -1 -- failed; errmsg() has reason
  */
-int Fl_Native_File_Chooser::show() { return _x11_file_chooser->show(); }
+int mgFl_Native_File_Chooser::show() { return _x11_file_chooser->show(); }
 
 
-Fl_FLTK_File_Chooser::Fl_FLTK_File_Chooser(int val) {
+mgFl_FLTK_File_Chooser::mgFl_FLTK_File_Chooser(int val) {
   _btype       = 0;
   _options     = 0;
   _filter      = NULL;
@@ -243,7 +228,7 @@ Fl_FLTK_File_Chooser::Fl_FLTK_File_Chooser(int val) {
   _nfilters    = 0;
 } 
 
-Fl_FLTK_File_Chooser::~Fl_FLTK_File_Chooser() {
+mgFl_FLTK_File_Chooser::~mgFl_FLTK_File_Chooser() {
   delete _file_chooser;
   _file_chooser = NULL;
   _filter      = strfree(_filter);
@@ -256,49 +241,49 @@ Fl_FLTK_File_Chooser::~Fl_FLTK_File_Chooser() {
 
 
 // PRIVATE: SET ERROR MESSAGE
-void Fl_FLTK_File_Chooser::errmsg(const char *msg) {
+void mgFl_FLTK_File_Chooser::errmsg(const char *msg) {
   _errmsg = strfree(_errmsg);
   _errmsg = strnew(msg);
 }
 
 // PRIVATE: translate Native types to Fl_File_Chooser types
-int Fl_FLTK_File_Chooser::type_fl_file(int val) {
+int mgFl_FLTK_File_Chooser::type_fl_file(int val) {
   switch (val) {
-    case Fl_Native_File_Chooser::BROWSE_FILE:
+    case mgFl_Native_File_Chooser::BROWSE_FILE:
       return(Fl_File_Chooser::SINGLE);
-    case Fl_Native_File_Chooser::BROWSE_DIRECTORY:
+    case mgFl_Native_File_Chooser::BROWSE_DIRECTORY:
       return(Fl_File_Chooser::SINGLE | Fl_File_Chooser::DIRECTORY);
-    case Fl_Native_File_Chooser::BROWSE_MULTI_FILE:
+    case mgFl_Native_File_Chooser::BROWSE_MULTI_FILE:
       return(Fl_File_Chooser::MULTI);
-    case Fl_Native_File_Chooser::BROWSE_MULTI_DIRECTORY:
+    case mgFl_Native_File_Chooser::BROWSE_MULTI_DIRECTORY:
       return(Fl_File_Chooser::DIRECTORY | Fl_File_Chooser::MULTI);
-    case Fl_Native_File_Chooser::BROWSE_SAVE_FILE:
+    case mgFl_Native_File_Chooser::BROWSE_SAVE_FILE:
       return(Fl_File_Chooser::SINGLE | Fl_File_Chooser::CREATE);
-    case Fl_Native_File_Chooser::BROWSE_SAVE_DIRECTORY:
+    case mgFl_Native_File_Chooser::BROWSE_SAVE_DIRECTORY:
       return(Fl_File_Chooser::DIRECTORY | Fl_File_Chooser::MULTI | Fl_File_Chooser::CREATE);
     default:
       return(Fl_File_Chooser::SINGLE);
   }
 }
 
-void Fl_FLTK_File_Chooser::type(int val) {
+void mgFl_FLTK_File_Chooser::type(int val) {
   _btype = val;
   _file_chooser->type(type_fl_file(val));
 }
 
-int Fl_FLTK_File_Chooser::type() const {
+int mgFl_FLTK_File_Chooser::type() const {
   return(_btype);
 }
 
-void Fl_FLTK_File_Chooser::options(int val) {
+void mgFl_FLTK_File_Chooser::options(int val) {
   _options = val;
 }
 
-int Fl_FLTK_File_Chooser::options() const {
+int mgFl_FLTK_File_Chooser::options() const {
   return(_options);
 }
 
-int Fl_FLTK_File_Chooser::show() {
+int mgFl_FLTK_File_Chooser::show() {
 
   // FILTER
     if ( _parsedfilt ) {
@@ -323,7 +308,7 @@ int Fl_FLTK_File_Chooser::show() {
     }
 
     // OPTIONS: PREVIEW
-    _file_chooser->preview( (options() & Fl_Native_File_Chooser::PREVIEW) ? 1 : 0);
+    _file_chooser->preview( (options() & mgFl_Native_File_Chooser::PREVIEW) ? 1 : 0);
   
     // SHOW
     _file_chooser->show();
@@ -339,7 +324,7 @@ int Fl_FLTK_File_Chooser::show() {
       _filtvalue = _file_chooser->filter_value(); // update filter value
 
       // HANDLE SHOWING 'SaveAs' CONFIRM
-      if ( options() & Fl_Native_File_Chooser::SAVEAS_CONFIRM && type() == Fl_Native_File_Chooser::BROWSE_SAVE_FILE ) {
+      if ( options() & mgFl_Native_File_Chooser::SAVEAS_CONFIRM && type() == mgFl_Native_File_Chooser::BROWSE_SAVE_FILE ) {
         struct stat buf;
         if ( stat(_file_chooser->value(), &buf) != -1 ) {
           if ( buf.st_mode & S_IFREG ) {    // Regular file + exists?
@@ -355,63 +340,63 @@ int Fl_FLTK_File_Chooser::show() {
     else return(1);
 }
 
-const char *Fl_FLTK_File_Chooser::errmsg() const {
+const char *mgFl_FLTK_File_Chooser::errmsg() const {
   return(_errmsg ? _errmsg : "No error");
 }
 
-const char* Fl_FLTK_File_Chooser::filename() const {
+const char* mgFl_FLTK_File_Chooser::filename() const {
   if ( _file_chooser->count() > 0 ) {
     return(_file_chooser->value());
   }
   return("");
 }
 
-const char* Fl_FLTK_File_Chooser::filename(int i) const {
+const char* mgFl_FLTK_File_Chooser::filename(int i) const {
     if ( i < _file_chooser->count() )
         return(_file_chooser->value(i+1));  // convert fltk 1 based to our 0 based
   return("");
 }
 
-void Fl_FLTK_File_Chooser::title(const char *val) {
+void mgFl_FLTK_File_Chooser::title(const char *val) {
   _file_chooser->label(val);
 }
 
-const char *Fl_FLTK_File_Chooser::title() const {
+const char *mgFl_FLTK_File_Chooser::title() const {
     return(_file_chooser->label());
 }
 
-void Fl_FLTK_File_Chooser::filter(const char *val) {
+void mgFl_FLTK_File_Chooser::filter(const char *val) {
   _filter = strfree(_filter);
   _filter = strnew(val);
   parse_filter();
 }
 
-const char *Fl_FLTK_File_Chooser::filter() const {
+const char *mgFl_FLTK_File_Chooser::filter() const {
   return(_filter);
 }
 
-int Fl_FLTK_File_Chooser::filters() const {
+int mgFl_FLTK_File_Chooser::filters() const {
   return(_nfilters);
 }
 
-void Fl_FLTK_File_Chooser::filter_value(int val) {
+void mgFl_FLTK_File_Chooser::filter_value(int val) {
   _filtvalue = val;
 }
 
-int Fl_FLTK_File_Chooser::filter_value() const {
+int mgFl_FLTK_File_Chooser::filter_value() const {
   return _filtvalue;
 }
 
-int Fl_FLTK_File_Chooser::count() const {
+int mgFl_FLTK_File_Chooser::count() const {
   return _file_chooser->count();
 }
 
-void Fl_FLTK_File_Chooser::directory(const char *val) {
+void mgFl_FLTK_File_Chooser::directory(const char *val) {
   _directory = strfree(_directory);
   _directory = strnew(val);
 }
 
-const char *Fl_FLTK_File_Chooser::directory() const {
+const char *mgFl_FLTK_File_Chooser::directory() const {
   return _directory;
 }
 
@@ -425,7 +410,7 @@ const char *Fl_FLTK_File_Chooser::directory() const {
 //     Returns a modified version of the filter that the caller is responsible
 //     for freeing with strfree().
 //
-void Fl_FLTK_File_Chooser::parse_filter() {
+void mgFl_FLTK_File_Chooser::parse_filter() {
   _parsedfilt = strfree(_parsedfilt);	// clear previous parsed filter (if any)
   _nfilters = 0;
   char *in = _filter;
@@ -488,19 +473,17 @@ void Fl_FLTK_File_Chooser::parse_filter() {
   //NOTREACHED
 }
 
-void Fl_FLTK_File_Chooser::preset_file(const char* val) {
+void mgFl_FLTK_File_Chooser::preset_file(const char* val) {
   _preset_file = strfree(_preset_file);
   _preset_file = strnew(val);
 }
 
-const char* Fl_FLTK_File_Chooser::preset_file() const {
+const char* mgFl_FLTK_File_Chooser::preset_file() const {
   return _preset_file;
 }
 
-int Fl_FLTK_File_Chooser::exist_dialog() {
-  return fl_choice("%s", fl_cancel, fl_ok, NULL, Fl_Native_File_Chooser::file_exists_message);
+int mgFl_FLTK_File_Chooser::exist_dialog() {
+  return fl_choice("%s", fl_cancel, fl_ok, NULL, mgFl_Native_File_Chooser::file_exists_message);
 }
 
-//
-// End of "$Id: $".
-//
+#endif // SEAVIEW_FLTK_VERSION < 133
