@@ -97,11 +97,11 @@ void rank_name_callback( Fl_Widget *o, void *data)
 //concatenate target = target + source
 static void concatenate(SEA_VIEW *target, SEA_VIEW *source, bool want_addgaps, bool is_by_name, bool no_gui)
 {
-  int i, j, l, *found;
+  int i, j, l, *found, target_length = target->seq_length;
   char *gaps;
   if (is_by_name) {//concatenation by name
     if (want_addgaps) {
-      l = FL_max(target->seq_length, source->seq_length);
+      l = FL_max(target_length, source->seq_length);
       gaps = (char *)malloc(l + 1);
       memset(gaps, '-', l);
       found = (int *)calloc(target->tot_seqs + source->tot_seqs, sizeof(int));
@@ -109,11 +109,11 @@ static void concatenate(SEA_VIEW *target, SEA_VIEW *source, bool want_addgaps, b
     for (i = 0; i < source->tot_seqs; i++) {
       for (j = 0; j < target->tot_seqs; j++) if(strcmp(source->seqname[i], target->seqname[j]) == 0) break;
       if (j >= target->tot_seqs) {//seq in source absent from target
-	if ( !want_addgaps ) continue;
-	//add a gap-only sequence to target
-	add_seq_to_align(target, source->seqname[i], gaps, target->seq_length, no_gui);
-	j = target->tot_seqs - 1;
-	if (source->comments[i] != NULL) target->comments[j] = strdup(source->comments[i]);
+        if ( !want_addgaps ) continue;
+          //add a gap-only sequence to target
+        add_seq_to_align(target, source->seqname[i], gaps, target_length, no_gui);
+        j = target->tot_seqs - 1;
+        if (source->comments[i] != NULL) target->comments[j] = strdup(source->comments[i]);
       }
       l = target->each_length[j] + source->each_length[i];
       target->sequence[j] = (char *)realloc(target->sequence[j], l + 1);
@@ -125,12 +125,13 @@ static void concatenate(SEA_VIEW *target, SEA_VIEW *source, bool want_addgaps, b
     }
     if (want_addgaps) {
       for (j = 0; j < target->tot_seqs; j++) {
-	if (found[j]) continue;
-	//seqs from target only are concatenated with a gap-only sequence
-	l = target->each_length[j] + source->seq_length;
-	target->sequence[j] = (char *)realloc(target->sequence[j], l + 1);
-	memset(target->sequence[j] + target->each_length[j], '-', source->seq_length);
-	target->sequence[j][l] = 0;
+        if (found[j]) continue;
+        //seqs from target only are concatenated with a gap-only sequence
+        l = target->each_length[j] + source->seq_length;
+        target->sequence[j] = (char *)realloc(target->sequence[j], l + 1);
+        memset(target->sequence[j] + target->each_length[j], '-', source->seq_length);
+        target->sequence[j][l] = 0;
+        target->each_length[j] = l;
       }
       free(gaps); 
       free(found); 
