@@ -4,6 +4,8 @@
 #include <math.h>
 #define check_alloc(a,b) calloc(a,b)
 
+extern int tree_build_interrupted;
+
 /* globals */
 static double *rl[21];
 static double *tl0[64], *tl1[64], *tl2[64], *tti0[64], *tti1[64],*tti2[64], 
@@ -612,6 +614,7 @@ fastlwl(char **seq, int nbseq, int lgseq, double **ka, double **ks, double **vka
 
 	for (i = 0; i < nbseq - 1; i++) {
 		for (j = i + 1; j < nbseq; j++) {
+		  if(tree_build_interrupted) return 1;
 			l[0] = l[1] = l[2] = 0.;
 			ti[0] = ti[1] = ti[2] = tv[0] = tv[1] = tv[2] = 0.;
 
