@@ -5,9 +5,6 @@
 #include <FL/x.H>
 #include <FL/Fl_Sys_Menu_Bar.H>
 #include <FL/Fl_Help_View.H>
-#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
-#include <src/drivers/Quartz/Fl_Quartz_Graphics_Driver.H>
-#endif
 #include <FL/filename.H>
 #include <FL/fl_draw.H>
 #include <sys/stat.h>
@@ -20,11 +17,13 @@ static void file_receive_cb(const char *fname);
 static void show_apropos(Fl_Widget *, void *unused);
 void MG_apple_inits(void);
 void set_seaview_modified(SEA_VIEW *view, int ismodified);
-void windowmenuitem_callback(Fl_Widget *o, void *data);
-int find_windowmenuitem(Fl_Window *w);
-int add_windowmenuitem(const char *name, Fl_Window *w);
-void rename_windowmenuitem(const char *name, int rank);
-void delete_windowmenuitem(int rank);
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION < 104
+  void windowmenuitem_callback(Fl_Widget *o, void *data);
+  int find_windowmenuitem(Fl_Window *w);
+  int add_windowmenuitem(const char *name, Fl_Window *w);
+  void rename_windowmenuitem(const char *name, int rank);
+  void delete_windowmenuitem(int rank);
+#endif
 char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int, const char *directory);
 
 /* extern functions */
@@ -181,7 +180,7 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   [key makeKeyWindow];
   [preset release];
   [dir release];
-  if ( retval == NSOKButton ) {//read accessory view state
+  if ( retval == NSFileHandlingPanelOKButton ) {//read accessory view state
     printout_block = [blockview intValue];
     printout_fontsize = [fontview intValue];
     printout_black = [pdfmatrix selectedRow];
@@ -191,10 +190,11 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
     strcpy(pathname, [[[_panel URL] path] UTF8String]);
     }
   [_panel setAccessoryView:nil];
-  if ( retval == NSCancelButton ) return NULL;
+  if ( retval == NSFileHandlingPanelCancelButton ) return NULL;
   return pathname;
 }
 
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION < 104
 
 void windowmenuitem_callback(Fl_Widget *o, void *data)
 {
@@ -239,6 +239,9 @@ void delete_windowmenuitem(int rank)
   fl_sys_menu_bar->remove(rank);
 }
 
+#endif
+
+
 static void file_receive_cb(const char *fname)
 {
   SEA_VIEW *view;
@@ -293,10 +296,56 @@ static void show_apropos(Fl_Widget *w, void *unused)
   about->show();
 }
 
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 104
+
+static Fl_Window *merged;
+
+static bool merge_windows_for_class(Fl_Window *first)
+{
+  bool retval = false;
+  Fl_Window *win = first;
+  NSWindow *nsw = (NSWindow*)fl_xid(first), *nsw2;
+  while ((win = Fl::next_window(win)) != NULL) {
+    int diff = strcmp(win->xclass(), first->xclass());
+    if (win->parent() || diff) continue;
+    nsw2 = (NSWindow*)fl_xid(win);
+    [nsw2 addTabbedWindow:nsw ordered:NSWindowAbove];
+    retval = true;
+    if (!merged) merged = win;
+  }
+  return retval;
+}
+
+static void merge_windows_by_class_cb(Fl_Widget *, void *)
+{
+  merged = NULL;
+more:
+  Fl_Window *win = Fl::first_window();
+  NSWindow *nsw;
+  while (win) {
+    nsw = (NSWindow*)fl_xid(win);
+    if (!win->parent() && ![nsw tabbedWindows] && strcmp(win->xclass(), Fl_Window::default_xclass())) {
+      if (merge_windows_for_class(win)) goto more;
+    }
+    win = Fl::next_window(win);
+  }
+  if (merged) merged->show();
+}
+#endif // FLTK ≥ 1.4
+
 void MG_apple_inits(void)
 {
   fl_open_callback(file_receive_cb);
   fl_mac_set_about(show_apropos, NULL, 0);
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 104
+  Fl_Sys_Menu_Bar::create_window_menu();
+  int merge = fl_sys_menu_bar->find_index("Window/Merge All Windows");
+  if (merge >= 0) {
+    fl_sys_menu_bar->replace(merge, "Merge Windows by Class");
+    Fl_Menu_Item *item = (Fl_Menu_Item*)fl_sys_menu_bar->menu() + merge;
+    item->callback(merge_windows_by_class_cb);
+  }
+#endif
   Fl::set_font(FL_COURIER,"Courier");
   Fl::set_font(FL_COURIER_BOLD, (fl_mac_os_version >= 100500 ? "Courier-Bold" : "Courier Bold") );
   if (fl_mac_os_version >= 100500) { // it seems that Courier Oblique is not present on older OS
@@ -463,9 +512,17 @@ Copy_Surface::Copy_Surface(bool pict, int w, int h) : Fl_Surface_Device(NULL)
     }
   else {
     prepare_copy_pdf_and_pict(w, h);
+#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
+    driver(Fl_Graphics_Driver::newMainGraphicsDriver());
+#else
     driver(new Fl_Quartz_Graphics_Driver());
+#endif
     oldgc = fl_gc;
+#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
+    driver()->gc(gc);
+#else
     fl_gc = gc;
+#endif
     }
 }
 
@@ -558,7 +615,7 @@ void Copy_Surface::init_PDF_context(int w, int h)
   CGRect bounds = CGRectMake(0, 0, w, h );	
   pdfdata = CFDataCreateMutable(NULL, 0);
   CGDataConsumerRef myconsumer;
-  if (CGDataConsumerCreateWithCFData != NULL) { // true from 10.4
+  if (CGDataConsumerCreateWithCFData) { // true from 10.4
     myconsumer = CGDataConsumerCreateWithCFData (pdfdata);
   }
   else {
