@@ -84,8 +84,9 @@ void Fl_SVG_Graphics_Driver::draw(const char *str, int n, int x, int y) {
   // Caution: Internet Explorer ignores the xml:space="preserve" attribute
   // work-around: replace all spaces by no-break space = U+00A0 = 0xC2-0xA0 (UTF-8) before sending to IE
   fprintf(out_, "<text x=\"%d\" y=\"%d\" font-family=\"%s\"%s%s font-size=\"%d\" "
-	  "xml:space=\"preserve\" "
-	  " fill=\"rgb(%u,%u,%u)\">%.*s</text>\n",x, y, family_, bold_, style_, size(), red_, green_, blue_, n, str);
+          "xml:space=\"preserve\" "
+          " fill=\"rgb(%u,%u,%u)\" textLength=\"%d\">%.*s</text>\n",x, y, family_, bold_, style_, size(), red_, green_, blue_, (int)width(str, n), n, str);
+
 }
 
 void Fl_SVG_Graphics_Driver::draw(const char* str, int n, float fx, float fy) {
