@@ -44,6 +44,17 @@ public:
 	}
 };
 
+class LeafNameTrimmer : public Fl_Widget {
+public:
+  LeafNameTrimmer(int x, int y, int w, int h);
+  int handle(int event);
+  void process();
+  void process_to_labels();
+  void process_unrooted();
+  void draw();
+  int by_position();
+};
+
 struct FD_nj_plot {
 	char *tree_name;
 	char *tree_label;
@@ -115,6 +126,7 @@ struct FD_nj_plot {
   bool branch_width_as_support;
   float support_threshold_high;
   float support_threshold_low;
+  LeafNameTrimmer *leaf_trimmer;
 };
 
 extern Fl_Window *treedraw(char *tree, SEA_VIEW *view, const char *name, int from_tree_menu, int count = 1);
