@@ -612,7 +612,7 @@ void savedistinfile(matrix *mat, const char *dirname, const char *outfname)
 	fprintf(out, "%d\n", mat->n_otu);
 	for( i = 0; i < mat->n_otu - 1; i++) {
 		for( j = i + 1; j < mat->n_otu; j++) {
-			fprintf(out, "%.6f ", mat->dist[i][j]);
+			fprintf(out, "%g ", mat->dist[i][j]);
 			}
 		fputs("\n", out);
 		}
@@ -626,7 +626,7 @@ void savedistinfile(matrix *mat, const char *dirname, const char *outfname)
       char *n1 = mat->name[i];
       char *n2 = mat->name[j];
       if (strcmp(n1, n2) > 0) { char *p = n1; n1 = n2; n2 = p; }
-      fprintf(out, "%s,%s: %f\n", n1, n2, mat->dist[i][j]);
+      fprintf(out, "%s,%s: %g\n", n1, n2, mat->dist[i][j]);
     }
   }
   fclose(out);
@@ -1201,6 +1201,24 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 	  display_tree = put_names_back_in_tree(display_tree, truenames);
     //process bootstrap trees
     char *bootstrap_trees = NULL;
+    if (replicates > 0) {
+      sprintf(input, "%s.phy_phyml_boot_stats.txt", base_fname);
+      in = fopen(input, "r");
+      if (!in) {
+        sprintf(input, "%s.phy_phyml_boot_stats", base_fname);
+        in = fopen(input, "r");
+      }
+      if (in) { // compute the true # of bootstrap replicates because parallelized phyML can compute a few more
+        char line[150];
+        while ((p = fgets(line, sizeof(line), in))) {
+          while (*p == ' ') p++;
+          if (*p == '#') {
+            sscanf(p+1, "%d", &replicates);
+          }
+        }
+        fclose(in);
+      }
+    }
     if (replicates > 0 && b_keep_trees->value()) {
       sprintf(input, "%s.phy_phyml_boot_trees.txt", base_fname);
       in = fopen(input, "r");
