@@ -773,6 +773,18 @@ return ( (float)(total) / length ) <= 0.8 ;
 }
 
 
+int is_a_protein_alignment(SEA_VIEW *view)
+/* returns TRUE if alignment looks like protein data (less than 80% ACGTU) */
+{
+  char *seq;
+  for (int i = 0; i < view->tot_seqs; i++) {
+    seq = view->sequence[i];
+    while (*seq == '-') seq++;
+    if (*seq != 0) return is_a_protein_seq(view->sequence[i]);
+  }
+  return false;
+}
+
 int save_phylip_file(const char *fname, char **seq,
 	char **seqname, int totseqs, int *eachlength, region *region_used, 
 	int *sel_seqs, int tot_sel_seqs, int phylipwidnames)
@@ -1109,6 +1121,11 @@ for(num=0; num<totseqs; num++) {
 		  putc(' ', out); 
 		  p = comments[num] + 1;
 		  while(*p != '\n' && *p != 0) putc(*(p++), out);
+            int gc = get_ncbi_gc_from_comment(comments[num]);
+            char *q = strstr(comments[num], "/transl_table=");
+            if (gc > 1 && q != NULL && q >= p) {
+              fprintf(out, " /transl_table=%d", gc);
+            }
 		  }
 	  }
 	putc('\n', out);
@@ -2054,7 +2071,10 @@ SEA_VIEW* read_alignment_file(const char *infile )
   memset(view, 0, sizeof(SEA_VIEW));
   view->menubar = new Fl_Menu_Bar(0,0, 30, 30);
   view->menu_trees = new vlength_menu(view->menubar, "Trees", NULL, 0);
-  
+
+#ifndef R_OK
+#define R_OK 04
+#endif
   if (fl_access(infile, R_OK)) {
     fprintf(stderr, "File %s\nis not readable or does not exist", infile);
     return NULL;
@@ -2108,7 +2128,7 @@ SEA_VIEW* read_alignment_file(const char *infile )
     if(name_sp != NULL) free(name_sp);
   }
   if (view->tot_seqs == 0) return NULL;
-  if (file_format != NEXUS_FORMAT) view->protein = is_a_protein_seq(view->sequence[0]);
+  if (file_format != NEXUS_FORMAT) view->protein = is_a_protein_alignment(view);
   view->each_length = new int[view->tot_seqs];
   for (i = 0; i < view->tot_seqs; i++) {
     view->each_length[i] = strlen(view->sequence[i]);
