@@ -90,12 +90,12 @@ public:
 
 void my_watch_cursor(Fl_Window *win)
 {
-win->default_cursor(FL_CURSOR_WAIT); 
+if (win) win->default_cursor(FL_CURSOR_WAIT);
 }
 
 void fl_reset_cursor(Fl_Window *win)
 {
-win->default_cursor(FL_CURSOR_DEFAULT); 
+if (win) win->default_cursor(FL_CURSOR_DEFAULT); 
 }
 
 
